using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace LawnLogin {
	public partial class frmOptions : Form {
		public frmOptions(Settings settings) {
			InitializeComponent();

			// Load existing settings into the dialog components
			txtAccount.Text = settings.account;
			txtPassword.Text = settings.password;
			chkDisableISS.Checked = settings.disableISS;
			switch (settings.connectAction) {
				case ConnectAction.FullLogin:
					radFullLogin.Checked = true;
					break;
				case ConnectAction.ShowDialog:
					radShowDialog.Checked = true;
					break;
				case ConnectAction.DoNothing:
					radDoNothing.Checked = true;
					break;
			}
			chkDisableNotify.Checked = settings.disableNotify;
			chkAutoStart.Checked = settings.autoStart;
			try {
				cmbUpdateFreq.SelectedIndex = (int)settings.updateFrequency;		// in case the updateFrequency is not valid
			} catch (Exception) { };
		}

		private void frmOptions_Load(object sender, EventArgs e) {
			Program.DisableOptionsMenu();
		}

		private void frmOptions_FormClosed(object sender, FormClosedEventArgs e) {
			Program.EnableOptionsMenu();
		}

		private void btnCancel_Click(object sender, EventArgs e) {
			this.Close();
		}

		private void btnOK_Click(object sender, EventArgs e) {
			// Save the dialog values into the settings object
			Settings newSettings = new Settings();
			newSettings.account = txtAccount.Text;
			newSettings.password = txtPassword.Text;
			newSettings.disableISS = chkDisableISS.Checked;
			if (radFullLogin.Checked) {
				newSettings.connectAction = ConnectAction.FullLogin;
			} else if (radShowDialog.Checked) {
				newSettings.connectAction = ConnectAction.ShowDialog;
			} else {
				newSettings.connectAction = ConnectAction.DoNothing;
			}
			newSettings.disableNotify = chkDisableNotify.Checked;
			newSettings.autoStart = chkAutoStart.Checked;
			newSettings.updateFrequency = (UpdateFrequency)cmbUpdateFreq.SelectedIndex;

			// Tell the main class to save the new settings
			Program.UpdateSettings(newSettings);
			this.Close();
		}

		private void txtAccount_TextChanged(object sender, EventArgs e) {
			UpdateRadios();
		}

		private void txtPassword_TextChanged(object sender, EventArgs e) {
			UpdateRadios();
		}

		private void UpdateRadios() {
			// Only allow users to choose the fully automatic option if they have entered both a username and a password
			if (txtAccount.Text.Length > 0 && txtPassword.Text.Length > 0) {
				radFullLogin.Enabled = true;
				chkDisableNotify.Enabled = true;
			} else {
				radFullLogin.Enabled = false;
				chkDisableNotify.Enabled = false;
				if (radFullLogin.Checked) radShowDialog.Checked = true;		// if fully automatic was picked, change to show dialog (since full is now disabled)
			}
		}
	}
}